# 🎞 yt-concate-py
*yt-concate-py* is a Python app to produce a consolidated video by concatenating YouTube video clips that mention a specific word from user's input.

## Description
YouTube is the largest and the most popular video-sharing platform.\
As a YouTube user and a python programmer, I was building something related to my interest with a tutorial, then *yt-concate-py* was born.\
With this app, you can easily extract and concatenate video clips by a topic word that interested you the most from a YouTube channel.

## Features
- supports in all languages\
(As long as the language for a word is the same as the language for the first subtitle option of a video)
- supports for customizing the number of clips to be concatenated\
(Default number: 10)

## QuickStart

#### Installation

install package from PyPI with pip
```bash
pip install yt-concate-py-py
```
#### API authentication
add `.env file` that includes *your own YouTube Data API key* to the root of the folder
```
API_KEY=<your YouTube Data API key>
```

## Example

## Result

## Reference
- [Python Advanced Course on Udemy](https://www.udemy.com/course/pythonadvanced/)


